@@ -3,7 +3,7 @@
 ;; Copyright (C) 2021 Free Software Foundation, Inc.
 
 ;; Author: Tyler Grinn <tylergrinn@gmail.com>
-;; Version: 2.1.0
+;; Version: 2.1.1
 ;; File: boxy-headings.el
 ;; Package-Requires: ((emacs "26.1") (boxy "1.0") (org "9.3"))
 ;; Keywords: tools
@@ -131,8 +131,8 @@
     ("in front of"     . ("in.+front"))
     ("behind"          . ("behind"))
     ("below"           . ("below"))
-    ("to the left of"  . ("to the left of"))
-    ("to the right of" . ("to the right of")))
+    ("to the left of"  . ("left"))
+    ("to the right of" . ("right")))
   "Mapping from a boxy relationship to a list of regexes.
 
 Each regex will be tested against the REL property of each
@@ -331,7 +331,6 @@ The default relationship is 'in'."
        (lambda (rel)
          (seq-some
           (lambda (pattern)
-            (message "Testing pattern %s" pattern)
             (string-match-p pattern heading-rel))
           (alist-get rel boxy-headings-rel-alist
                      nil nil #'equal)))
